.. image:: _static/docs-logo.png
    :width: 140px
    :alt: Moccasin logo
    :align: center


Moccasin
######

Moccasin is a fast, pythonic smart contract development framework heavily powered by `titanoboa <https://github.com/vyperlang/titanoboa>`_.


.. note::

   This project is under active development.

How to read the documentation
=============================

The moccasin documentation is written in a way that assumes you are on a MacOS or Linux-like system. If you are using windows, we recommend you watch the first `10 minutes of this WSL tutorial <https://www.youtube.com/watch?v=xqUZ4JqHI_8>`_ and work with WSL. WSL stands for "Windows Subsystem for Linux" and it allows you to run a Linux commands on Windows machine.

Why Moccasin?
===========

We think web3 needs the following:

1. A python smart contract development framework.
    a. We need this because python is the 2nd most popular language on earth, and is the number one choice for artificial intelligence and new computer engineers!
2. An easy way to run devops on contracts.
    a. Running scripts to interact with contracts needs to be easy in a language that humans can understand.
3. And finally... it needs to be fast!

Then, we have some fun plans for AI, formal verification, fuzzing, and more in the future of moccasin, so stay tuned!


Head over to :doc:`installing moccasin <installing-moccasin>` to get started.